@@ -78,6 +78,10 @@ elif get_backend()=='onnx':
     import_or_install('onnx_runtime')
     pass
 
+from trident.data.image_common import *
+from trident.data.bbox_common import *
+from trident.data.label_common import *
+from trident.data.mask_common import *
 from trident.data.transform import *
 from trident.data.vision_transforms import *
 from trident.data.text_transforms import *
