@@ -302,7 +302,7 @@ def adaptive_format(num: numbers.Number, prev_value: Union[numbers.Number, Itera
             return '{0:.3%}'.format(num)
         elif len(prev_value) > 0:
             digit = int(np.array([builtins.abs(builtins.min(math.log10(builtins.abs(s)), 0)) + 3 if s != 0 else 0 for s in prev_value]).mean())
-            if digit > 6:
+            if digit > 8:
                 return '{0:{1}}'.format(num, '.3e')
             elif digit < 4:
                 return '{0:{1}}'.format(num, '.3f')
@@ -320,17 +320,19 @@ def adaptive_format(num: numbers.Number, prev_value: Union[numbers.Number, Itera
             if math.modf(num)[0] == 0:
                 num = int(num)
                 return '{0:,}'.format(num)
-            elif 1.2 >= num >= 0.001 or -0.001 >= num >= -1.2 or num == 0:
+            elif 1.5 >= num >= 0.001 or -0.001 >= num >= -1.5 or num == 0:
                 return '{0:.3%}'.format(num)
-            elif num > 4.2 or num < -4.2:
-                return '{0:{1}}'.format(num, '.3f')
-            else:
+            elif 10000<num  or num <= -10000:
                 return '{0:{1}}'.format(num, '.3e')
+            else:
+                return '{0:{1}}'.format(num, '.3f')
+
         elif value_type != 'loss':
-            if 1000 >= num >= 0.001 or -0.001 >= num >= -1000 or num == 0:
-                return '{0:{1}}'.format(num, '.3f')
-            else:
+            if 10000< num or  num <= -10000 :
                 return '{0:{1}}'.format(num, '.3e')
+            else:
+                return '{0:{1}}'.format(num, '.3f')
+
 
         return '{0:{1}}'.format(num, format_string)
 
@@ -1808,13 +1810,13 @@ def is_instance(instance, check_class):
     if not inspect.isclass(instance) and inspect.isclass(check_class):
         mro_list = [b.__module__ + '.' + b.__qualname__ for b in instance.__class__.__mro__]
         return check_class.__module__ + '.' + check_class.__qualname__ in mro_list
-    elif not inspect.isclass(instance) and isinstance(check_class, str):
+    elif  isinstance(check_class, str):
         mro_list = [b.__module__ + '.' + b.__qualname__ for b in instance.__class__.__mro__]
         mro_list2 = [b.__qualname__ for b in instance.__class__.__mro__]
         return check_class in mro_list or check_class in mro_list2
     else:
         if not inspect.isclass(check_class):
-            print(red_color('Input check_class should a class, but {0}'))
+            print(red_color('Input check_class {0} should a class, but {1}'.format(check_class,type(check_class))))
         return False
 
 
