@@ -243,33 +243,33 @@ class ModelBase(object):
         return self._metrics
 
     def update_signature(self, arg_names):
-        if self.model is not None and hasattr(self.model, 'signature') and self.signature != self.model.signature:
-            self.signature = self.model.signature
+        if self.model is not None and hasattr(self.model, 'signature') and self._signature != self.model.signature:
+            self._signature = self.model.signature
 
-        if self.signature is not None and len(self.signature.inputs.key_list) == len(arg_names):
-            old_inputs = copy.deepcopy(self.signature.inputs)
-            self.signature.inputs = OrderedDict()
+        if self._signature is not None and len(self._signature.inputs.key_list) == len(arg_names):
+            old_inputs = copy.deepcopy(self._signature.inputs)
+            self._signature.inputs = OrderedDict()
             self.inputs = OrderedDict()
             for i in range(len(old_inputs)):
                 spec = old_inputs[i]
                 spec.name = arg_names[i]
-                self.signature.inputs[arg_names[i]] = spec
+                self._signature.inputs[arg_names[i]] = spec
                 self.inputs[arg_names[i]] = spec
 
 
-        elif self.signature is not None and len(self.signature.inputs.key_list) + len(self.signature.outputs.key_list) == len(arg_names):
+        elif self._signature is not None and len(self._signature.inputs.key_list) + len(self._signature.outputs.key_list) == len(arg_names):
 
-            old_inputs = copy.deepcopy(self.signature.inputs)
-            old_outputs = copy.deepcopy(self.signature.outputs)
-            self.signature.inputs = OrderedDict()
-            self.signature.outputs = OrderedDict()
+            old_inputs = copy.deepcopy(self._signature.inputs)
+            old_outputs = copy.deepcopy(self._signature.outputs)
+            self._signature.inputs = OrderedDict()
+            self._signature.outputs = OrderedDict()
             self.inputs = OrderedDict()
             self._outputs = OrderedDict()
             self._targets = OrderedDict()
             for i in range(len(old_inputs)):
                 spec = old_inputs[i]
                 spec.name = arg_names[i]
-                self.signature.inputs[arg_names[i]] = spec
+                self._signature.inputs[arg_names[i]] = spec
                 self.inputs[arg_names[i]] = spec
 
             for i in range(len(old_inputs)):
@@ -279,14 +279,14 @@ class ModelBase(object):
 
                 spec = old_outputs[i]
                 spec.name = arg_names[i + len(old_inputs)]
-                self.signature.outputs[arg_names[i + len(old_inputs)]] = spec
+                self._signature.outputs[arg_names[i + len(old_inputs)]] = spec
                 self._outputs[arg_names[i + len(old_inputs)]] = spec
                 self._targets[target_arg] = spec
 
-            print(self.signature)
+            print(self._signature)
         elif not isinstance(arg_names, (list, tuple)):
             raise ValueError('arg_names should be list or tuple')
-        elif len(self.signature) != len(arg_names):
+        elif len(self._signature) != len(arg_names):
             raise ValueError('data feed and arg_names should be the same length')
 
     @property
@@ -661,7 +661,11 @@ class ModelBase(object):
                     data[k] = v
 
             else:
-                data[self.signature.outputs.key_list[0]] = output
+                if self._signature.outputs is None or len(self._signature.outputs)==0:
+                    self._signature.outputs['output']=TensorSpec.tensor_to_spec(output)
+                    data[self._signature.outputs.key_list[0]] = output
+                else:
+                    data[self._signature.outputs.key_list[0]] = output
                 if is_training and self.use_output_as_loss:
                     this_loss = output.sum()
                     self.training_context['current_loss'] = self.training_context['current_loss'] + this_loss
@@ -947,7 +951,7 @@ class ModelBase(object):
             if 'skip_generate_output' not in self.training_context or self.training_context['skip_generate_output'] == False:
                 try:
                     if self.output_fn is not None and callable(self.output_fn):
-                        self.output_fn(self.training_context, is_training=True, is_autocast_enabled=self.is_autocast_enabled)
+                        self.output_fn(self,self.training_context, is_training=True, is_autocast_enabled=self.is_autocast_enabled)
                     else:
                         self.do_calculate_forward(is_training=True)
 
@@ -1013,8 +1017,7 @@ class ModelBase(object):
                     test_steps, test_values = self.training_context['out_sample_metrics'].get_series(k)
                     metric_value = test_values[-1]
                     history_metric_value = to_scalar(test_values[-1])
-
-                    verbose.append('{0}: {1}'.format(k, adaptive_format(metric_value)))
+                    verbose.append('{0}: {1}'.format(k, adaptive_format(metric_value,prev_value=test_values,value_type='metric')))
                 out_sample_evaluation_str = cyan_color(self.training_context['model_name'] + ' ' + 'out-of-sample evaluation: ' + ','.join(verbose))
                 print(out_sample_evaluation_str)
             # self.training_context['steps'] += 1
