@@ -1,38 +1,33 @@
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
-import matplotlib.pyplot as plt
-import math
+
+import numbers
 import os
-import sys
-import warnings
 import time
+
+import matplotlib.pyplot as plt
 import numpy as np
 import torch
-from trident.data.dataset import MaskDataset, ZipDataset
 
 from trident import context
-import numbers
 from trident.backend.common import *
-from trident.backend.load_backend import *
-from trident.backend.pillow_backend import image2array
 from trident.callbacks.callback_base import CallbackBase
+from trident.data.bbox_common import *
+from trident.data.dataset import MaskDataset, ZipDataset
 from trident.data.image_common import image_backend_adaption
 from trident.data.mask_common import label2color
 from trident.misc.ipython_utils import is_in_ipython, is_in_colab
 from trident.misc.visualization_utils import *
-from trident.data.bbox_common import *
 
 if get_backend() == 'pytorch':
     from trident.backend.pytorch_backend import try_map_args_and_call, Layer
-    from trident.backend.pytorch_ops import to_numpy, to_tensor, arange, shuffle, cast, clip, sqrt, int_shape, argmax, softmax, any_abnormal_number, reduce_any, ndim, exp, \
-        concate, \
+    from trident.backend.pytorch_ops import to_numpy, arange, cast, clip, sqrt, int_shape, argmax, softmax, ndim, exp, \
         expand_dims
 
 elif get_backend() == 'tensorflow':
     from trident.backend.tensorflow_backend import try_map_args_and_call, Layer
-    from trident.backend.tensorflow_ops import to_numpy, to_tensor, arange, shuffle, cast, clip, sqrt, int_shape, concate, zeros_like, ones_like, argmax, softmax, concate, \
-        any_abnormal_number, ndim, exp, not_equal, reduce_any, expand_dims
+    from trident.backend.tensorflow_ops import to_numpy, arange, cast, clip, sqrt, int_shape, zeros_like, ones_like, argmax, softmax, ndim, exp, not_equal, expand_dims
 
 if is_in_ipython() or is_in_colab():
     from IPython import display
