@@ -172,15 +172,15 @@ class VisionTransform(Transform):
         else:
             if ndim(boxes) == 1:
                 boxes=np.expand_dims(boxes,0)
-
+            B=boxes.shape[0]
             location= boxes[:, :4]
             class_info = boxes[:, 4:5] if boxes.shape[-1]>4 else None
             keypoints = boxes[:, 5:] if boxes.shape[-1]>5 else None
             idxs = np.array([(0, 1), (2, 1), (0, 3), (2, 3)]).flatten()
-            coords = np.asarray(location).reshape(-1, 4)[:, idxs].reshape(-1, 2)
-            coords = self._apply_coords(coords,spec).reshape((-1, 4, 2))
-            minxy = coords.min(axis=1)
-            maxxy = coords.max(axis=1)
+            location = np.asarray(location).reshape(-1, 4)[:, idxs].reshape(-1, 2)
+            location = self._apply_coords(location,spec).reshape((-1, 4, 2))
+            minxy = location.min(axis=1)
+            maxxy = location.max(axis=1)
             if keypoints is not None:
                 coords_keypoints = np.asarray(keypoints).reshape(-1, 2)
                 keypoints = self._apply_keypoints(coords_keypoints, spec).reshape((-1, keypoints.shape[-1]))
