@@ -186,6 +186,7 @@ def download_file_from_google_drive(file_id, dirname=None, filename=None, md5=No
     """
     # Based on https://stackoverflow.com/questions/38511444/python-download-files-from-google-drive-using-url
     import requests
+
     url = "https://drive.google.com/uc?export=download"
     if not dirname:
         dirname=os.path.join(get_trident_dir(),'downloads')
@@ -202,19 +203,16 @@ def download_file_from_google_drive(file_id, dirname=None, filename=None, md5=No
         return True
     else:
         try:
-            DLFile=urllib.request.urlopen(url+"&id="+file_id)
-
-
             session = requests.Session()
-            # response = session.get(url, params={'id': file_id}, stream=True)
-            #
-            # token = _get_confirm_token(response)
-            # if token:
-            #     params = {'id': file_id, 'confirm': token}
-            response = session.get(DLFile.url,  stream=True)
+            response = session.get(url, params={'id': file_id}, stream=True)
+            content_type = response.headers.get('content-type')
+
+
+            token = _get_confirm_token(response)
+            if token:
+                params = {'id': file_id, 'confirm': token}
+                response = session.get(url, params=params, stream=True)
             _save_response_content(response, dest_path)
-            _write_h(dirname, True, False, filename)
-            return True
         except Exception as e:
             _write_h(dirname, False, False, filename)
             print('***Cannot download data, so the data provider cannot initialized.\n', flush=True)
@@ -575,47 +573,51 @@ def extract_archive(file_path, target_folder=None, archive_format='auto'):
         True if a match was found and an archive extraction was completed,
         False otherwise.
     """
-    folder, file, ext = split_path(file_path)
-    _h = _read_h(target_folder)
-    filename = file + ext
-    is_extracted = _h[filename].get('is_extracted', False) if filename in _h else _h.get('is_extracted', False)
-    if _h != {} and is_extracted == True and os.path.exists(file_path):
-        print('extraction is finished, donnot need extract again.')
-        return True
-    if archive_format is None:
-        return False
-    if archive_format == 'auto':
-        archive_format = ['tar', 'zip']
-    if isinstance(archive_format, six.string_types):
-        archive_format = [archive_format]
-
-    is_match_fn = tarfile.is_tarfile
-    open_fn = tarfile.open
-    for archive_type in archive_format:
-        if archive_type == 'tar':
-            open_fn = tarfile.open
-            is_match_fn = tarfile.is_tarfile
-        if archive_type == 'zip':
-            open_fn = zipfile.ZipFile
-            is_match_fn = zipfile.is_zipfile
-
-        if is_match_fn(file_path):
-            print('Starting to decompress the archive....')
-            with open_fn(file_path) as archive:
-                try:
-                    archive.extractall(target_folder)
-                    _write_h(target_folder, True, True)
-                except (tarfile.TarError, RuntimeError, KeyboardInterrupt):
-                    sys.stderr.write('Decompressing the archive is not success')
-                    PrintException()
-                    _write_h(target_folder, True, False, filename)
-                    if os.path.exists(target_folder):
-                        shutil.rmtree(target_folder)
-                    raise
-            _write_h(target_folder, True, True, filename)
+    try:
+        folder, file, ext = split_path(file_path)
+        _h = _read_h(target_folder)
+        filename = file + ext
+        is_extracted = _h[filename].get('is_extracted', False) if filename in _h else _h.get('is_extracted', False)
+        if _h != {} and is_extracted == True and os.path.exists(file_path):
+            print('extraction is finished, donnot need extract again.')
             return True
-        else:
-            _write_h(target_folder, True, False, filename)
+        if archive_format is None:
+            return False
+        if archive_format == 'auto':
+            archive_format = ['tar', 'zip']
+        if isinstance(archive_format, six.string_types):
+            archive_format = [archive_format]
+
+        is_match_fn = tarfile.is_tarfile
+        open_fn = tarfile.open
+        for archive_type in archive_format:
+            if archive_type == 'tar':
+                open_fn = tarfile.open
+                is_match_fn = tarfile.is_tarfile
+            if archive_type == 'zip':
+                open_fn = zipfile.ZipFile
+                is_match_fn = zipfile.is_zipfile
+
+            if is_match_fn(file_path):
+                print('Starting to decompress the archive....')
+                with open_fn(file_path) as archive:
+                    try:
+                        archive.extractall(target_folder)
+                        _write_h(target_folder, True, True)
+                    except (tarfile.TarError, RuntimeError, KeyboardInterrupt):
+                        sys.stderr.write('Decompressing the archive is not success')
+                        PrintException()
+                        _write_h(target_folder, True, False, filename)
+                        if os.path.exists(target_folder):
+                            shutil.rmtree(target_folder)
+                        raise
+                _write_h(target_folder, True, True, filename)
+                return True
+            else:
+                _write_h(target_folder, True, False, filename)
+    except Exception as e:
+        print(e)
+        _write_h(dirname, False, False, filename)
     return False
 
 
