@@ -25,7 +25,7 @@ __all__ = ['Resize', 'ShortestEdgeResize', 'Rescale', 'RandomCrop', 'RandomResca
            'RandomAdjustSaturation','AutoLevel',
            'Normalize', 'Unnormalize', 'CLAHE', 'Lighting', 'HorizontalFlip', 'RandomMirror', 'AdjustGamma', 'RandomBlur', 'RandomAdjustGamma', 'Blur', 'InvertColor',
            'RandomInvertColor', 'GrayScale', 'RandomGrayScale',
-           'ImageDilation', 'ImageErosion', 'ErosionThenDilation', 'DilationThenErosion', 'AdaptiveBinarization', 'SaltPepperNoise', 'RandomErasing', 'ToRGB', 'ImageMosaic']
+           'ImageDilation', 'ImageErosion', 'ErosionThenDilation', 'DilationThenErosion', 'AdaptiveBinarization', 'SaltPepperNoise', 'RandomErasing', 'ToRGB', 'ImageMosaic','DetectionMixup']
 
 
 def randomize_with_validate(valid_range=None, no_change_value=None, **kwargs):
@@ -627,7 +627,7 @@ class RandomTransformAffine(VisionTransform):
 
         if self._shape_info is None:
             self._shape_info = self._get_shape(image)
-        mat_img, height, width, is_flip ,rr= self._shape_info
+        mat_img, height, width,angle, is_flip ,rr= self._shape_info
 
         if rr>self.keep_ratio:
             image = np.clip(image.astype(np.float32), 0, 255)[:, :, :3]
@@ -651,24 +651,28 @@ class RandomTransformAffine(VisionTransform):
             return image
 
     def _apply_coords(self, coords, spec: TensorSpec):
-        mat_img, height, width, is_flip,rr = self._shape_info
+        mat_img, height, width,angle, is_flip,rr = self._shape_info
         if rr>self.keep_ratio:
-            #
+
             coords = coords.transpose([1, 0])
             coords = np.insert(coords, 2, 1, axis=0)
             # # print(coords)
             # # print(transform_matrix)
             coords_result = np.matmul(mat_img, coords)
             coords_result = coords_result[0:2, :].transpose([1, 0])
+
             if is_flip:
-                coords_result[:, 0::2] = width - coords_result[:, 0::2]
+                if coords.shape[-1] == 4:
+                    coords = np.stack([width - coords[..., 2], coords[..., 1], width - coords[..., 0], coords[..., 3]], axis=-1)
+                elif coords.shape[-1] == 2:
+                    coords[..., 0] = width - coords[..., 0]
             return coords_result
         else:
             return coords
 
     def _apply_mask(self, mask, spec: TensorSpec):
         mask = unpack_singleton(mask)
-        mat_img, height, width, is_flip,rr = self._shape_info
+        mat_img, height, width,angle, is_flip,rr = self._shape_info
         if rr>self.keep_ratio:
             mask_dtype = mask.dtype
             mask = mask.astype(np.float32)
@@ -756,7 +760,7 @@ class RandomTransformAffine(VisionTransform):
 
         rr_flip= np.random.random()
         rr= np.random.random()
-        return np.array(matrix).reshape((2, 3)), h, w, rr_flip < self.random_flip,rr
+        return np.array(matrix).reshape((2, 3)), h, w,angle, rr_flip < self.random_flip,rr
 
 
 RandomTransform = RandomTransformAffine
@@ -811,11 +815,46 @@ class HorizontalFlip(VisionTransform):
         if self._shape_info is None:
             self._shape_info = self._get_shape(image)
         height, width = self._shape_info
-        return image[:, ::-1]
+        return np.fliplr(image)
 
     def _apply_coords(self, coords, spec: TensorSpec):
         height, width = self._shape_info
-        coords[:, 0::2] = width - coords[:, 0::2]
+        if coords.shape[-1]==4:
+            coords=np.stack([width-coords[..., 2],coords[..., 1],width-coords[..., 0], coords[..., 3]],axis=-1)
+        elif coords.shape[-1]==2:
+            coords[..., 0]=width-coords[..., 0]
+        return coords
+
+    def _apply_mask(self, mask, spec: TensorSpec):
+        mask = unpack_singleton(mask)
+        height, width = self._shape_info
+        return mask[:, ::-1]
+
+    def _get_shape(self, image):
+        height, width, _ = image.shape
+        return height, width
+
+class VerticalFlip(VisionTransform):
+    def __init__(self, name='vertical_flip', **kwargs):
+        super().__init__(name)
+        self.is_spatial = True
+
+    def apply(self, input: Tuple, spec: TensorSpec):
+        return super().apply(input, spec)
+
+    def _apply_image(self, image, spec: TensorSpec):
+        image = unpack_singleton(image)
+        if self._shape_info is None:
+            self._shape_info = self._get_shape(image)
+        height, width = self._shape_info
+        return np.flipud(image)
+
+    def _apply_coords(self, coords, spec: TensorSpec):
+        height, width = self._shape_info
+        if coords.shape[-1]==4:
+            coords=np.stack([coords[..., 0],height-coords[..., 3],coords[..., 2], height-coords[..., 1]],axis=-1)
+        elif coords.shape[-1]==2:
+            coords[..., 1]=height-coords[..., 1]
         return coords
 
     def _apply_mask(self, mask, spec: TensorSpec):
@@ -1712,6 +1751,99 @@ class RandomErasing(VisionTransform):
     def _apply_mask(self, mask, spec: TensorSpec):
         return mask
 
+
+class DetectionMixup(VisionTransform):
+    """Perform gamma correction on an image.
+        Also known as Power Law Transform. Intensities in RGB mode are adjusted
+        based on the following equation:
+        I_out = 255 * gain * ((I_in / 255) ** gamma)
+        See https://en.wikipedia.org/wiki/Gamma_correction for more details.
+    Args:
+        gamma (float): Non negative real number. gamma larger than 1 make the
+            shadows darker, while gamma smaller than 1 make dark regions
+            lighter.
+        gain (float): The constant multiplier.
+    """
+
+    def __init__(self, output_size=None, keep_prob=0.8, name='detection_mixup', **kwargs):
+        super().__init__(name)
+        self.alpha=1
+        self.output_size = output_size
+        self.keep_prob = keep_prob
+        self.memory_cache=[]
+
+
+
+    def _apply_image(self, image, spec: TensorSpec):
+        image = unpack_singleton(image)
+
+        if self._shape_info is None:
+            self._shape_info = self._get_shape(image)
+        keep, other_idx, lam = self._shape_info
+        if keep:
+            return image
+        height, width = self.output_size
+        background = np.zeros((height, width, 3))
+        p1 = self.memory_cache[other_idx][spec].copy()
+        p1 = p1[:builtins.min(height, p1.shape[0]), :builtins.min(width, p1.shape[1]):]
+        background[:p1.shape[0], :p1.shape[1], :] = p1
+        mixed_x = lam * image + (1 - lam) * background
+
+        return clip(mixed_x, 0, 255).astype(np.float32)
+
+
+    def _apply_coords(self, coords, spec: TensorSpec):
+
+        return coords
+
+    def _apply_boxes(self, boxes, spec: TensorSpec):
+        keep, other_idx, lam = self._shape_info
+        if keep:
+            return boxes
+        height, width = self.output_size
+        box1 = self.memory_cache[other_idx][spec].copy()
+        B = boxes.shape[0]
+        location = boxes[:, :4]
+        class_info = boxes[:, 4:5] if boxes.shape[-1] > 4 else None
+        keypoints = boxes[:, 5:] if boxes.shape[-1] > 5 else None
+
+        location1 = box1[:, :4].reshape((box1.shape[0], 2, 2))
+        class_info1 = box1[:, 4:5] if box1.shape[-1] > 4 else None
+        keypoints1 = box1[:, 5:].reshape((box1.shape[0], -1, 2)) if box1.shape[-1] > 5 else None
+
+        location1[:, :, 0] = np.clip(location1[:, :, 0], 0, width)
+        keypoints1[:, :, 0] = np.clip(keypoints1[:, :, 0], 0, width)
+        location1[:, :, 1] = np.clip(location1[:, :, 1], 0, height)
+        keypoints1[:, :, 1] = np.clip(keypoints1[:, :, 1], 0, height)
+        box1 = np.concatenate([location1.reshape((B, -1)), class_info1, keypoints1.reshape((B, -1))], axis=-1)
+
+        trans_boxes = np.concatenate([boxes, box1], axis=0)
+        return trans_boxes
+
+
+    def _apply_mask(self, mask, spec: TensorSpec):
+         return mask
+
+
+    def _get_shape(self, image):
+        if self.output_size is None:
+            self.output_size=image.shape[:2]
+        rr = random.random()
+        keep=rr<self.keep_prob or len(self.memory_cache[:-1])<=3
+        other_idxes=None
+        other_idx=None
+        lam =0
+        if not keep:
+            other_idxes = list(range(len(self.memory_cache[:-1])))
+            random.shuffle(other_idxes)
+            other_idx =other_idxes[0]
+
+            height, width = self.output_size
+            lam = builtins.min(builtins.max(np.random.beta(self.alpha, self.alpha), 0.3), 0.7)
+
+
+        return keep,other_idx,lam
+
 class ImageMosaic(VisionTransform):
     """Perform gamma correction on an image.
         Also known as Power Law Transform. Intensities in RGB mode are adjusted
@@ -1757,43 +1889,31 @@ class ImageMosaic(VisionTransform):
 
 
     def _apply_coords(self, coords, spec: TensorSpec):
-        keep, other_idxes, center,img1_offsetx,img1_offsety,img2_offsetx,img2_offsety,img3_offsetx,img3_offsety = self._shape_info
+        return coords
+
+    def _apply_boxes(self, boxes,spec:TensorSpec):
+        keep, other_idxes, center, img1_offsetx, img1_offsety, img2_offsetx, img2_offsety, img3_offsetx, img3_offsety = self._shape_info
         if keep:
-            return coords
-        height,width=self.output_size
-        box0 =coords.copy()
-        box0[:, 0] = np.clip(box0[ :, 0], 0, center[1])
-        box0[:, 1] = np.clip(box0[:, 1], 0, center[0])
+            return boxes
+        height, width = self.output_size
+        box1 = self.memory_cache[other_idxes[0]][spec].copy()
+        B=boxes.shape[0]
+        location= boxes[:, :4]
+        class_info = boxes[:, 4:5] if boxes.shape[-1]>4 else None
+        keypoints = boxes[:, 5:] if boxes.shape[-1]>5 else None
 
-        idxs = np.array([(0, 1), (2, 1), (0, 3), (2, 3)]).flatten()
+        location1 = box1[:, :4].reshape((box1.shape[-1],2,2))
+        class_info1 = box1[:, 4:5] if box1.shape[-1] > 4 else None
+        keypoints1 = box1[:, 5:].reshape((box1.shape[-1],-1,2)) if box1.shape[-1] > 5 else None
 
+        location1[:,:,0]=np.clip(location1[:,:,0],0,width)
+        keypoints1[:, :, 0] = np.clip(keypoints1[:, :, 0], 0, width)
+        location1[:, :, 1] = np.clip(location1[:, :, 1], 0, height)
+        keypoints1[:, :, 1] = np.clip(keypoints1[:, :, 1], 0, height)
+        box1=np.concatenate([location1.reshape((B,-1)),class_info1,keypoints1.reshape((B,-1))],axis=-1)
 
-        box1 = self.memory_cache[other_idxes[0]][spec].copy()[:,:4]
-        box1 = np.asarray(box1).reshape(-1, 4)[:, idxs].reshape(-1, 2)
-            #.reshape(coords.shape[0],-1,2)
-        box1[:, 0] = np.clip(box1[:, 0], img1_offsetx,img1_offsetx+width-center[1])
-        box1[:, 1] = np.clip(box1[:, 1], img1_offsety,img1_offsety+center[0])
-
-
-        box2 = self.memory_cache[other_idxes[1]][spec].copy()[:,:4]
-        box2= np.asarray(box2).reshape(-1, 4)[:, idxs].reshape(-1, 2)
-        box2[:, 0] = np.clip(box2[:, 0], img2_offsetx,img2_offsetx+center[1])
-        box2[:, 1] = np.clip(box2[:, 1], img2_offsety,img2_offsety+height-center[0])
-
-
-        box3 = self.memory_cache[other_idxes[2]][spec].copy()[:,:4]
-        box3 = np.asarray(box3).reshape(-1, 4)[:, idxs].reshape(-1, 2)
-        box3[:, 0] = np.clip(box3[ :, 0], img3_offsetx,img3_offsetx+width-center[1])
-        box3[ :, 1] = np.clip(box3[:, 1], img3_offsety,img3_offsety+height-center[0])
-
-        box_list=np.concatenate([box0,box1,box2,box3],axis=0)
-        box_list=box_list.reshape(-1,4)
-        hw = np.clip(box_list[..., 2:] - box_list[..., :2], 0.0, None)
-        area=hw[..., 0] * hw[..., 1]
-        mask_box=area>0
-        mask_box=box_list[mask_box,:]
-        return mask_box
-
+        trans_boxes=np.concatenate([boxes,box1],axis=0)
+        return trans_boxes
 
 
     def _apply_mask(self, mask, spec: TensorSpec):
