@@ -51,7 +51,7 @@ if not os.path.exists(dirname):
 
 model_urls = {
     'resnet18': '156C4a0_nts8QbjCE8YWbA-QbvCnTrfb5',
-    'resnet50': '1dYlgpFtqi87KDG54_db4ALWKLARxCWMS',
+    'resnet50': '1R_Ae0DiElUX6yiLqbnq93Iw6vIhaA929',
     'resnet101': '17moUOsGynsWALLHyv3yprHWbbDMrdiOP',
     'resnet152': '1BIaHb7_qunUVvt4TDAwonSKI2jYg4Ybj',
 }
