@@ -471,7 +471,7 @@ def RfbNet(include_top=True,
         input_shape = tuple(input_shape)
     else:
         input_shape = (3, 480, 640)
-    rfbnet = SsdDetectionModel(input_shape=(3, 480, 640), output=RFBnet(base_filters=base_filters, num_classes=num_classes, num_regressors=num_regressors))
+    rfbnet = SsdDetectionModel(input_shape=input_shape, output=RFBnet(base_filters=base_filters, num_classes=num_classes, num_regressors=num_regressors))
     rfbnet.detection_threshold=0.7
     rfbnet.nms_threshold=0.7
     rfbnet.palette[0] = (128, 255, 128)
