@@ -2,6 +2,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 import copy
+import gc
 import inspect
 import json
 import math
@@ -513,8 +514,8 @@ class TrainingPlan(object):
             self.do_on_training_start()
             for epoch in range(self.num_epochs):
                 self.epochs=epoch
-                try:
-                    for mbs, return_data in enumerate(data_provider):
+                for mbs, return_data in enumerate(data_provider):
+                    try:
 
                         if self.is_terminate:
                             for callback in self.callbacks:
@@ -522,11 +523,12 @@ class TrainingPlan(object):
                                     callback.on_training_terminated(self.__dict__)
 
                             for k, trainitem in self.training_items.items():
-
                                 for callback in trainitem.training_context['callbacks']:
                                     if not callback.is_shared:
                                         callback.on_training_terminated(trainitem.training_context)
                             data_provider.mode = 'tuple'
+                            return True
+
                         else:
 
                             iter_data = OrderedDict()
@@ -647,23 +649,26 @@ class TrainingPlan(object):
                             if only_steps == False and (mbs + 1) % len(data_provider.batch_sampler) == 0:
                                 break
 
+                    except RuntimeError as runtime_e:
+                        if 'CUDA out of memory' in str(runtime_e):
+                            gc.collect()
 
-                except StopIteration:
-                    for k, trainitem in self.training_items.items():
-                        trainitem.do_on_epoch_end()
-                        trainitem.save_model(trainitem.training_context['save_path'], )
+                    except StopIteration:
+                        for k, trainitem in self.training_items.items():
+                            trainitem.do_on_epoch_end()
+                            trainitem.save_model(trainitem.training_context['save_path'], )
 
-                except ValueError as ve:
-                    print(ve)
-                    PrintException()
-                    for k, trainitem in self.training_items.items():
-                        trainitem.do_on_excution_exception()
+                    except ValueError as ve:
+                        print(ve)
+                        PrintException()
+                        for k, trainitem in self.training_items.items():
+                            trainitem.do_on_excution_exception()
 
-                except Exception as e:
-                    print(e)
-                    PrintException()
-                    for k, trainitem in self.training_items.items():
-                        trainitem.do_on_excution_exception()
+                    except Exception as e:
+                        print(e)
+                        PrintException()
+                for k, trainitem in self.training_items.items():
+                    trainitem.do_on_excution_exception()
                 if self.save_model_frequency > 0 and self.save_model_unit == 'epoch' and (
                         epoch + 1) % self.save_model_frequency == 0:
                     for k, trainitem in self.training_items.items():
